.. _examples :

=================
Example Notebooks
=================

The following notebooks demonstrate several examples of using **smol** for various
applications.

You simply look open a static notebook by clicking it's link, or you can run the
notebooks interactively on Binder.

.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/CederGroupHub/smol/HEAD?labpath=docs%2Fsrc%2Fnotebooks%2Findex.ipynb


Basic Examples
--------------

- `Creating a basic cluster expansion`_
- `Creating a cluster expansion with electrostatics`_
- `Visualizing clusters`_
- `Choosing site basis sets`_
- `Running canonical Monte Carlo`_
- `Running semigrand canonical Monte Carlo`_
- `Running charge neutral semigrand canonical Monte Carlo`_
- `Setting number of threads for OpenMP parallelization`_


.. _Creating a basic cluster expansion: notebooks/creating-a-ce.ipynb

.. _Creating a cluster expansion with electrostatics: notebooks/creating-a-ce-w-electrostatics.ipynb

.. _Visualizing clusters: notebooks/cluster-visualization.ipynb

.. _Choosing site basis sets: notebooks/choosing-site-basis-sets.ipynb

.. _Running Canonical Monte Carlo: notebooks/running-canonical-mc.ipynb

.. _Running Semigrand Canonical Monte Carlo: notebooks/running-semigrand-mc.ipynb

.. _Running Charge Neutral Semigrand Canonical Monte Carlo: notebooks/running-charge-balanced-gcmc.ipynb

.. _Setting number of threads for OpenMP parallelization: notebooks/openmp-parallelism.ipynb


Advanced Examples
-----------------

- `Preparing cluster expansion training data`_
- `Centering training data in stage-wise fit with electrostatics`_
- `Adding structures to a StructureWrangler in parallel`_
- `Simulated annealing with point electrostatics`_
- `Choosing Monte Carlo kernels and step types`_
- `Wang-Landau sampling of an FCC Ising model`_
- `Generating special quasirandom structures`_
- `Solving for periodic ground-states`_
- `Li-Mn-O DRX cluster expansion and sampling`_

.. _Preparing cluster expansion training data: notebooks/training-data-preparation.ipynb

.. _Centering training data in stage-wise fit with electrostatics: notebooks/ce-fit-w-centering.ipynb

.. _Adding structures to a StructureWrangler in parallel: notebooks/adding-structures-in-parallel.ipynb

.. _Simulated annealing with point electrostatics: notebooks/running-ewald-sim_anneal.ipynb

.. _Choosing Monte Carlo kernels and step types: notebooks/advanced-mc-settings.ipynb

.. _Wang-Landau sampling of an FCC Ising model: notebooks/wang-landau-ising.ipynb

.. _Generating special quasirandom structures: notebooks/generating-sqs.ipynb

.. _Solving for periodic ground-states: notebooks/finding-groundstates.ipynb

.. _Li-Mn-O DRX cluster expansion and sampling: notebooks/lmo-drx-ce-mc.ipynb

More to come...
